---
layout: post.html
title: "Meetup Alternatives"
date: 2019-10-21
tags: Meetup
summary: "A look at the various alternatives to Meetup.com after recent online backlash to their proposed new pricing model."
---

# Intro

Meetup.com recently has suffered from some [backlash](https://twitter.com/securestep9/status/1183798804371386369) to some [new pricing models](https://www.meetup.com/lp/payment-test-20191016) it proposed. They have since [backpedaled](https://www.meetup.com/lp/paymentchanges?mpId=9038) but for many the damage has already been done and the trust has been damaged. This comes two years after Meetup [made some changes](https://lab.io/articles/2017/11/08/dear-meetup/) that made it significantly worse for organisers to manage their communities as well as being taken over by WeWork who are currently facing financial difficulties - something many have suggested as the reason for exploring new profitability strategies with Meetup.com. Following Meetup rescinding their proposed payment model I have since received an email informing me that my organiser subscription will be increasing from $14.99/month to $16.49/month.

All this was the last straw for me, I have been unhappy with the service Meetup provides for quite a while now so I spent some time to evaluate the various alternatives to see what would be best suited for [JSOxford](https://jsoxford.com/) and [BerkshireJS](https://berkshirejs.com/). Hopefully this will also be useful for other organisers.

> The alternatives listed here are presented in no particular order.
>
> I am not affiliated with any of the services presented here.

---

## Confetti

[https://confetti.events/en/](https://confetti.events/en/)

<div style="display: flex;flex-direction: row;flex-wrap: wrap;">
  <div style="width: 50%;min-width: 400px;">

### Pros

- Free (with limitations)
- iPhone and Android app
- Custom CSS, Favicon and signup form
- Waitlist
- Ticket batches
- Supports ticketed and RSVP events (tickets can be free)
- Very quick and easy sign up
- Custom domain support (paid)
- Supports multi-page event pages
- Nice content editor
  </div>
  <div style="width: 50%;min-width: 400px;">

### Cons

- Events archived 30days after the event has ended
- Emails not included (paid extra)
- Single person can edit the account
- Each event is created in isolation (e.g. you'd need a new page created for each meetup each month)
- Paid features expensive (~£350 per **EVENT**)
  </div>
</div>


### Comments

Would be really nice for one-off / less frequent events (conference, workshop, etc) but not really aimed at monthly meetups.

---

## Get Together

[https://gettogether.community/](https://gettogether.community/)

<div style="display: flex;flex-direction: row;flex-wrap: wrap;">
  <div style="width: 50%;min-width: 400px;">

### Pros

- Open source ([https://github.com/GetTogetherComm/GetTogether](https://github.com/GetTogetherComm/GetTogether))
- Community built
- Easy signup + social logins
- UI isn't the most intuitive
  </div>
  <div style="width: 50%;min-width: 400px;">

### Cons

- Still very sparse
- Still lacking in features
  </div>
</div>


### Comments

Shows promise but too early in it's life to be considered at this point.

---

## Tito

[https://ti.to/home](https://ti.to/home)

<div style="display: flex;flex-direction: row;flex-wrap: wrap;">
  <div style="width: 50%;min-width: 400px;">

### Pros

- Free for free events
- Can be embedded into own website
- Secret tickets - Useful for sending to speakers, sponsors etc. to ensure they get a space
- Can collect information from attendees
- Check-in apps for iOS and Android
- Event teams
- Wait lists
- Messaging
- Custom domain support
  </div>
  <div style="width: 50%;min-width: 400px;">

### Cons

- Only handles tickets, no RSVP
- Event page sparse and lacking rich customisation
  </div>
</div>


### Comments

Used and trusted by many paid events. Would work best if coupled with own website

---

## Kommunity

[https://kommunity.com/](https://kommunity.com/)

<div style="display: flex;flex-direction: row;flex-wrap: wrap;">
  <div style="width: 50%;min-width: 400px;">

### Pros

- Features similar to Meetup
- "Import from meetup" feature
- Google analytics support
- Contact members
  </div>
  <div style="width: 50%;min-width: 400px;">

### Cons

- Currently no events listed in the UK
- Very basic page customisation / styling
- Very basic event description formatting. Single text entry with ability to only create headings, links and bold text.
- Lacks a list of all available features
  </div>
</div>


### Comments

Not just tech focussed. Looks like a good contender for those looking for a like-for-like experience (especially for the users), the import from meetup feature also aids with this.

---

## Get Invited

[https://getinvited.to/](https://getinvited.to/)

<div style="display: flex;flex-direction: row;flex-wrap: wrap;">
  <div style="width: 50%;min-width: 400px;">

### Pros

- Free for free events
- Create event pages
- Embed into your own website
- Ask attendee questions
- Hidden tickets (for speakers, sponsors, etc. to make sure they get a place)
- Wait list
  </div>
  <div style="width: 50%;min-width: 400px;">

### Cons

- No text styling on event page
- Limited customisation of event page (heading images and colour)
  </div>
</div>


### Comments

May work best embedded into own website. Minimal event page may be useful for those who don't mind the limited styling.

---

## OpenCollective

[https://opencollective.com/](https://opencollective.com/)

### Comments

Really only useful if you already have an OpenCollective as has limited features and styling but allows ticket sales to go directly into OpenCollective account (useful for sponsors)

---

## Eventbrite

[https://www.eventbrite.co.uk/](https://www.eventbrite.co.uk/)

<div style="display: flex;flex-direction: row;flex-wrap: wrap;">
  <div style="width: 50%;min-width: 400px;">

### Pros

- Free for free events
- Fundraising integrations
- Custom URL
- Wait list
- HTML editor available for event description
- Robust event admin dashboard
- Contact attendees
  </div>
  <div style="width: 50%;min-width: 400px;">

### Cons

- Own site integration requires "Professional" package
- Standard page layout. Very obviously an Eventbrite page
- Focused on events, not groups (e.g. events aren't linked under the organisation group)
- Not just tech focussed
  </div>
</div>


### Comments

Great option for those that like stats and keeping track of how their event is doing numbers-wise. The lack of the concept of a group that hosts events is a bit of a letdown and would require some other mechanism to encourage discoverability. Feature set comparable to that of Meetup plus extra. Events are discoverable but the vast variety in the types of events would make actual discovery of meetups difficult.

---

## Attendize

[https://www.attendize.com/index.html](https://www.attendize.com/index.html)

<div style="display: flex;flex-direction: row;flex-wrap: wrap;">
  <div style="width: 50%;min-width: 400px;">

### Pros

- Self hosted
- Open source ([https://github.com/Attendize/Attendize](https://github.com/Attendize/Attendize))
- Rich event description editing
- Message attendees
- Limited styling of tickets
- Web-based checkin functionality
- Surveys
- Embed in your own website
- Has ability for organisers pages (but extremely limited in style and features)
- Supports multiple organisers
  </div>
  <div style="width: 50%;min-width: 400px;">

### Cons

- No hosted / managed version available
- Event page layout not configurable (but as open source the layout could be modified in code)
- No way to delete tickets, events, orgs, etc.
  </div>
</div>


### Comments

Uses a Attribution Assurance Licence so event pages must display "Powered by Attendize", paid licenses available.

---

## Alf

[https://alf.io/](https://alf.io/)

<div style="display: flex;flex-direction: row;flex-wrap: wrap;">
  <div style="width: 50%;min-width: 400px;">

### Pros

- Self hosted
- Open source ([https://github.com/alfio-event/alf.io](https://github.com/alfio-event/alf.io))
- Checkin support
- Google analytics support
  </div>
  <div style="width: 50%;min-width: 400px;">

### Cons

- No hosted / manages version available
- Demo didn't work for me
  </div>
</div>


### Comments

Might be nice, couldn't test it so can't say.

---

## Meetabit

[https://meetabit.com/](https://meetabit.com/)

<div style="display: flex;flex-direction: row;flex-wrap: wrap;">
  <div style="width: 50%;min-width: 400px;">

### Pros

- Focussed on tech
- Supports concept of organisations that have events
- Has ability to propose a talk via the organisation page
- Has dedicated space on event page for the talks to be listed
- Supports external registration pages (could be run alongside meetup with meetup handling the RSVPs)
  </div>
  <div style="width: 50%;min-width: 400px;">

### Cons

- Interface quite sparse but content cluttered together
- Discoverability of events is a bit awkward with only a dropdown list of specific cities from around the world to select from (not grouped by country)
- Unable to create new community as location wasn't listed
- Lacking in details that can be populated about a community
- Unable to view existing members of a group other than organisers (make discovering new events you may like harder)
  </div>
</div>


### Comments

Has potential but seems too early days currently. The business model around it seems like it'll be focussed ads alongside communities / events based on the company behind it being a recruitment agency.

---

## Chapter

[https://github.com/freeCodeCamp/chapter](https://github.com/freeCodeCamp/chapter)

<div style="display: flex;flex-direction: row;flex-wrap: wrap;">
  <div style="width: 50%;min-width: 400px;">

### Pros

- Open Source
- Self-hosted
  </div>
  <div style="width: 50%;min-width: 400px;">

### Cons

- Nothing has been built yet!!!
  </div>
</div>


### Comments

This is a weird one to add as it's by no means a viable option yet as nothing has been built but as it's still in the initial development stage it's good to be aware of so features, requirements and annoyances with existing platforms can be fed in early. This promises a lot and at this stage it's impossible to say if I can deliver on all of them.

---

## Codemotion Community

[https://community.codemotion.com/](https://community.codemotion.com/)

<div style="display: flex;flex-direction: row;flex-wrap: wrap;">
  <div style="width: 50%;min-width: 400px;">

### Pros

- Tech focussed
- Similar event page layout to meetup
- Images can be used without event description
  </div>
  <div style="width: 50%;min-width: 400px;">

### Cons

- Doesn't list attendees
- Currently limited to four countries it seems
  </div>
</div>


### Comments

I was unable to create an account so couldn't test out the full features. This alone made me discount this as an option.

---

## Emamo

[https://emamo.com](https://emamo.com/)

<div style="display: flex;flex-direction: row;flex-wrap: wrap;">
  <div style="width: 50%;min-width: 400px;">

### Pros

- Manage multiple events under an organisation
- Supports multiple admins
- Gives the ability to add a relevant hashtag for the event
- Ability to add admin-only notes to sessions
- Ability to add sponsors to an event
- Create multi-page event sites
- Ability to message attendees
  </div>
  <div style="width: 50%;min-width: 400px;">

### Cons

- Expensive, cheapest tier: Up to 1000 Attendees: $50/month or $500/year
- No styling options
- Seems more focussed towards conference style events with the ability to have multiple tracks and build an agenda
- No way to limit number of attendees
  </div>
</div>


### Comments

Some nice features but seems more driven towards the corporate market catering for multi-event conferences. Free tier is misleading as only the admins of that org can then see the events.

---

## AllEvents.in

[https://allevents.in](https://allevents.in/)

<div style="display: flex;flex-direction: row;flex-wrap: wrap;">
  <div style="width: 50%;min-width: 400px;">

### Pros

- Very similar feel and approach as meetup
- Ability to search for everything within a location (city) and then filter down by category (there is a meetup category)
- Plenty of information on the event pages
- Supports external ticket / RSVP sites
  </div>
  <div style="width: 50%;min-width: 400px;">

### Cons

- Not tech focussed
- Limited styling and formatting available
  </div>
</div>


### Comments

I'm not quite sure what it is but something puts me off wanting to use this site.  If looking for a like-for-like replacement for meetup this may be worth looking at.

---

## Eventsyay

[https://eventyay.com/](https://eventyay.com/)

<div style="display: flex;flex-direction: row;flex-wrap: wrap;">
  <div style="width: 50%;min-width: 400px;">

### Pros

- Basic event description styling
- Ability to add a CoC to an event
- Built in ticketing with some advanced config
  </div>
  <div style="width: 50%;min-width: 400px;">

### Cons

- Google maps integration is broken
- Some broken links
- Limited locations currently
- Focussed on individual events, not communities
- Signup email doesn't actually contain email verification, you need to trigger it again
  </div>
</div>


### Comments
This looks like it could be nice for individual events in the future but I encountered too many errors and bugs in my short evaluation to be able to recommend it. I didn't even manage to complete the "Create event" flow.

---

## Mixily

[https://www.mixily.com/](https://www.mixily.com/)

<div style="display: flex;flex-direction: row;flex-wrap: wrap;">
  <div style="width: 50%;min-width: 400px;">

### Pros

- Really nice event creation interface
- No account needed to create a demo event
- Message attendees
- Ability to manually add RSVPs
- Attendees don't need an account to RSVP
- RSVPs can send messages to host with their RSVP status
  </div>
  <div style="width: 50%;min-width: 400px;">

### Cons

- No description formatting
- Single events, no communities
- Lacking any event page styling beyond a header image
- No discoverability, only via direct link / email
  </div>
</div>


### Comments
A nice and simple, single-event service that could be nice for quick and easy one-off events. No mention of how the service makes money or similar makes me skeptical.

---

## Helm

[https://helmtickets.com/](https://helmtickets.com/)

<div style="display: flex;flex-direction: row;flex-wrap: wrap;">
  <div style="width: 50%;min-width: 400px;">

### Pros

- Free for free events
  </div>
  <div style="width: 50%;min-width: 400px;">

### Cons

- Focused on ticketing rather than events
- Event page lacking in styling capabilities
  </div>
</div>

### Comments
This is yet another service that I encountered issues with, I was unable to register for an account with an unspecified error consistently presenting itself.

---

## Tech Talks

[https://techtalks.io/](https://techtalks.io/)

<div style="display: flex;flex-direction: row;flex-wrap: wrap;">
  <div style="width: 50%;min-width: 400px;">

### Pros

- A focus on tech events.
- Generous free tier offering unlimited events and members.
- Big focus on supporting and fostering the tech community.
- Great support for both virtual and physical events.
- Includes a profile for speakers to include their talks slides and videos which can be used by other event organisers to discover new speakers for their events.
- A strong focus on making the content from events available by including videos from events.
- Also provides a tier aimed at those running a conference.
- Communities also have a place for discussions and <abbr title="Today I Learnt">TIL's</abbr> with a very nice rich text editor.
- Communities can have multiple organisers.
  </div>
  <div style="width: 50%;min-width: 400px;">

### Cons

- Limited branding available (colour, logo and header).
- Limitation on avatar and logo sizes - uploaded image must be square, no option to crop.
- No ability to create draft or hidden events.
  </div>
</div>

### Comments

I'm really liking TechTalks and think it has a lot of potential. It's set up by [Adam Butler](https://twitter.com/labfoo) who wrote the blog post several years back that I linked to in the into section. With the focus on fostering community and providing a focused place to tech-related events I think this has a lot of promise to be a much sought after replacement for Meetup for a log of events.

---

# Wrap up

I don't see any clear winner that will suit everyone as a replacement to Meetup but I do think there is something in this list for everyone. There's a lot of strong contenders here (especially if you already have a website where you post events) and even more with future potential. The major thing all these options lack is the discoverability that Meetup provides but I feel this is likely to change as people more to alternatives.

# _Changelog_

* 2019-10-21 - Migrated from a [Notion page](https://www.notion.so/jsoxford/Meetup-Alternatives-36d73649d34f4bba9e2065f1fa8cd03f) to my blog. Added Eventsyay, Mixily and Helm.
* 2020-09-30 - Added section covering TechTalks.io.
